FlutterPushBase class abstract

Developers should not use this field directly This class is the base class for Flutter layer access device processing. If you need to implement Push capability for a new channel directly at Flutter layer, please inherit this class.

Implementers

Constructors

FlutterPushBase()

Properties

hashCode → int
The hash code for this object.
no setterinherited
onClickNotification ↔ PushClickAction?
Developers should not use this field directly Bind the click callback
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token ↔ String
Developers should not use this field directly Device Token
getter/setter pair

Methods

getToken() → Future<String?>
Developers should not use this field directly Get device Token
init(PushClickAction onClickNotificationFunction) → Future<void>
Developers should not use this field directly Initialize the push capability
isSupport() → Future<bool>
Developers should not use this field directly Determin whether the device supports push for each channel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requirePermission() → void
Developers should not use this field directly Require push permission
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited