GoogleFCMImpl class

Inheritance

Constructors

GoogleFCMImpl()

Properties

googleFCMMessaging → FirebaseMessaging
Developers should not use this field directly Initialize Google Firebase Messaging Plug-in
final
hashCode → int
The hash code for this object.
no setterinherited
onClickNotification ↔ PushClickAction?
Developers should not use this field directly Bind the click callback
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token ↔ String
Developers should not use this field directly Device Token
getter/setter pairinherited

Methods

getToken() → Future<String?>
Developers should not use this field directly Get Google FCM Token
override
init(PushClickAction onClickNotificationFunction) → Future<void>
Developers should not use this field directly Initialize Google FCM
override
isSupport() → Future<bool>
Developers should not use this field directly Determin whether the device support Google Service and Google FCM
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requirePermission() → void
Developers should not use this field directly Require push permission via Google
override
setupGoogleInteractedMessage() → Future<void>
Developers should not use this field directly Listen notification message from Google FCM
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited