PushDeviceConfig class

Constructors

PushDeviceConfig({String? deviceManufacturer, int? businessID, String? deviceToken})

Properties

businessID ↔ int?
The corresponding business ID of current device on Tencent Cloud IM console.
getter/setter pair
deviceManufacturer ↔ String?
Device manufacturer
getter/setter pair
deviceToken ↔ String?
Device push token, sometimes been called as 'register ID'.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited